==> leechcraft-0.3.80_rc20101109.tar.bz2: leechcraft-0.3.75_rc20101109/src/plugins/tabpp/leechcraft_tabpp_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en_US">
<context>
    <name>LeechCraft::Plugins::TabPP::Core</name>
    <message>
        <location filename="core.cpp" line="281"/>
        <source>unknown</source>
        <translation>unknown</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::TabPP::Plugin</name>
    <message>
        <location filename="tabpp.cpp" line="66"/>
        <source>Enhances user experience with tabs.</source>
        <translation>Enhances user experience with tabs.</translation>
    </message>
    <message>
        <location filename="tabpp.cpp" line="124"/>
        <source>Show tab switcher</source>
        <translation>Show tab switcher</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::TabPP::TabPPWidget</name>
    <message>
        <location filename="tabppwidget.cpp" line="44"/>
        <source>F9</source>
        <translation>F9</translation>
    </message>
</context>
<context>
    <name>tabppsettings</name>
    <message>
        <location filename="dummyfile.cpp" line="2"/>
        <source>Settings</source>
        <translation>Settings</translation>
    </message>
    <message>
        <location filename="dummyfile.cpp" line="3"/>
        <source>Behavior</source>
        <translation>Behavior</translation>
    </message>
    <message>
        <location filename="dummyfile.cpp" line="4"/>
        <source>Show on action hover</source>
        <translation>Show on action hover</translation>
    </message>
    <message>
        <location filename="dummyfile.cpp" line="5"/>
        <source>Focus on the tab list after show</source>
        <translation>Focus on the tab list after show</translation>
    </message>
    <message>
        <location filename="dummyfile.cpp" line="6"/>
        <source>Hide on Ctrl+Enter</source>
        <translation>Hide on Ctrl+Enter</translation>
    </message>
</context>
</TS>

==> leechcraft-0.4.75_rc20110524.tar.bz2: leechcraft-0.4.75_rc20110524/src/plugins/tabpp/leechcraft_tabpp_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en_US">
<context>
    <name>LeechCraft::Plugins::TabPP::Core</name>
    <message>
        <location filename="core.cpp" line="281"/>
        <source>unknown</source>
        <translation>unknown</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::TabPP::Plugin</name>
    <message>
        <location filename="tabpp.cpp" line="72"/>
        <source>Enhances user experience with tabs.</source>
        <translation>Enhances user experience with tabs.</translation>
    </message>
    <message>
        <location filename="tabpp.cpp" line="123"/>
        <source>Show tab switcher</source>
        <translation>Show tab switcher</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::TabPP::TabPPWidget</name>
    <message>
        <location filename="tabppwidget.cpp" line="44"/>
        <source>F9</source>
        <translation>F9</translation>
    </message>
</context>
<context>
    <name>tabppsettings</name>
    <message>
        <location filename="dummy.cpp" line="2"/>
        <source>Settings</source>
        <translation>Settings</translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="3"/>
        <source>Behavior</source>
        <translation>Behavior</translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="4"/>
        <source>Show on action hover</source>
        <translation>Show on action hover</translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="5"/>
        <source>Focus on the tab list after show</source>
        <translation>Focus on the tab list after show</translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="6"/>
        <source>Hide on Ctrl+Enter</source>
        <translation>Hide on Ctrl+Enter</translation>
    </message>
</context>
</TS>
